@@ -3,8 +3,8 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2012 Alexandru Munteanu
- * Contact: io_fx@yahoo.fr
+ * Copyright: (C) 2005-2014 Alexandru Munteanu
+ * Contact: m@ioalex.net
  *
  * http://mp3splt.sourceforge.net/
  *
@@ -24,7 +24,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
  * USA.
  *
  *********************************************************/
@@ -37,20 +37,29 @@
  * contain a valid file- or directory name.
  ********************************************************/
 
-#include <gtk/gtk.h>
-#include <stdlib.h>
-#include <string.h>
-#include <libmp3splt/mp3splt.h>
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <glib/gstdio.h>
+#include "utilities.h"
 
-#include "player.h"
-#include "preferences_tab.h"
-#include "main_win.h"
+/*!check if specified directory exists
+*/
+gint directory_exists(const gchar *directory)
+{
+  if (directory == NULL)
+  {
+    return FALSE;
+  }
 
-//!check if the string passed as an argument points to a file
-gint is_filee(const gchar *fname)
+  struct stat buffer;
+  gint status = g_stat(directory, &buffer);
+
+  if (status == 0 && S_ISDIR(buffer.st_mode) != 0)
+    return TRUE;
+
+  return FALSE;
+}
+
+/*! check if specified file exists
+*/
+gint file_exists(const gchar *fname)
 {
   if (fname == NULL)
   {
@@ -58,73 +67,24 @@ gint is_filee(const gchar *fname)
   }
 
   struct stat buffer;
-  gint         status;
+  gint status = g_stat(fname, &buffer);
 
-  status = g_stat(fname, &buffer);
-  if (status == 0)
-  {
-    //if it is a file
-    if (S_ISREG(buffer.st_mode) != 0)
-    {
-      return TRUE;
-    }
-    else
-    {
-      return FALSE;
-    }
-  }
-  else
-  {
-    return FALSE;
-  }
-}
-
-/*!check if a string points to a directory
-
-\todo why guchar?
-*/
-gint check_if_dir(guchar *fname)
-{
-  struct stat buffer;
-
-  g_stat((gchar *)fname, &buffer);
-
-  //if it is a directory
-  if (S_ISDIR(buffer.st_mode) != 0)
+  if (status == 0 && S_ISREG(buffer.st_mode) != 0)
     return TRUE;
-  else
-    return FALSE;
-}
 
-/*! check if a sting points to a file
-
-\todo
- - Why guchar ?
- - And what is the difference to is_filee?
-*/
-gint check_if_file(guchar *fname)
-{
-  struct stat buffer;
-
-  g_stat((gchar *)fname, &buffer);
-  //if it is a file
-  if (S_ISREG(buffer.st_mode) != 0)
-    return TRUE;
-  else
-    return FALSE;
+  return FALSE;
 }
 
 /*! Issues the message "Processing file <filename>" into the message bar
 
 \param filename The filename that has to be printed.
  */
-void print_processing_file(gchar *filename)
+void print_processing_file(gchar *filename, ui_state *ui)
 {
   gint fname_status_size = (strlen(filename) + 255);
   gchar *fname_status = g_malloc(sizeof(char) * fname_status_size);
-  g_snprintf(fname_status, fname_status_size,
-      _("Processing file '%s' ..."), filename);
-  put_status_message(fname_status);
+  g_snprintf(fname_status, fname_status_size, _("Processing file '%s' ..."), filename);
+  put_status_message_in_idle(fname_status, ui);
   if (fname_status)
   {
     free(fname_status);
@@ -132,32 +92,7 @@ void print_processing_file(gchar *filename)
   }
 }
 
-/*! Does this GtkContainer contain that object?
-
-\param GtkContainer The Container that has to be searched for the
-child object.
-\param my_child The child that has to be searched for.
- */
-gboolean container_has_child(GtkContainer *container, GtkWidget *my_child)
-{
-  GList *children = gtk_container_get_children(GTK_CONTAINER(container));
-  int i = 0;
-  GtkWidget *child = NULL;
-  while ((child = g_list_nth_data(children, i)) != NULL)
-  {
-    if (child == my_child)
-    {
-      return TRUE;
-    }
-    i++;
-  }
-
-  return FALSE;
-}
 /*! Removes trailing \\r or \\n characters from a filename
-
-\todo Cannot find any code that removes a trailing slash as this
-function would suggest
  */
 void remove_end_slash_n_r_from_filename(char *filename)
 {
@@ -193,29 +128,84 @@ chunk of memory to have somewhere to put the output string in - which
 means that the memory the output string is in has to be freed after usage. 
 \return 
 */
-gchar *transform_to_utf8(gchar *text, gint free_or_not,
-    gint *must_be_freed)
+gchar *transform_to_utf8(gchar *text, gint free_or_not, gint *must_be_freed)
 {
   gchar *temp;
 
   gsize bytes_read;
   gsize bytes_written;
 
-  if(!(g_utf8_validate (text, -1,NULL)) &&
-     (text != NULL))
+  if (!(g_utf8_validate (text, -1,NULL)) && (text != NULL))
+  {
+    temp = g_convert(text, -1, "UTF-8", "ISO-8859-1", &bytes_read, &bytes_written, NULL);
+    if (free_or_not)
     {
-      temp = g_convert(text, -1, "UTF-8", "ISO-8859-1", &bytes_read, &bytes_written, NULL);
-      if (free_or_not)
-        g_free(text);
-          
-      *must_be_freed = TRUE;
-          
-      return temp;
+      g_free(text);
     }
-  
+
+    *must_be_freed = TRUE;
+
+    return temp;
+  }
+
   *must_be_freed = FALSE;
-  
+
   return text;
 }
 
+void build_path(GString *path, const gchar *dir, const gchar *filename)
+{
+#ifdef __WIN32__
+  g_string_assign(path, ".");
+  g_string_append(path, G_DIR_SEPARATOR_S);
+  g_string_append(path, filename);
+#else
+  if (strlen(dir) == 0)
+  {
+    g_string_assign(path, filename);
+  }
+  else 
+  {
+    g_string_assign(path, dir);
+    g_string_append(path, G_DIR_SEPARATOR_S);
+    g_string_append(path, filename);
+  }
+#endif
+}
+
+gboolean double_equals(gdouble double_to_compare, gdouble compared_value)
+{
+  return fabs(double_to_compare - compared_value) < DOUBLE_PRECISION;
+}
+
+//points and tags utilities
+
+points_and_tags *new_points_and_tags()
+{
+  points_and_tags *pat = g_malloc(sizeof(points_and_tags));
+  pat->splitpoints = g_ptr_array_new();
+  pat->tags = g_ptr_array_new();
+  return pat;
+}
+
+void free_points_and_tags(points_and_tags **pat)
+{
+  if (!pat || !*pat) { return; }
+  g_ptr_array_free((*pat)->splitpoints, SPLT_TRUE);
+  (*pat)->splitpoints = NULL;
+  g_ptr_array_free((*pat)->tags, SPLT_TRUE);
+  (*pat)->tags = NULL;
+  g_free(*pat);
+  *pat = NULL;
+}
+
+void append_point_to_pat(splt_point *point, points_and_tags *pat)
+{
+  g_ptr_array_add(pat->splitpoints, point);
+}
+
+void append_tags_to_pat(splt_tags *tags, points_and_tags *pat)
+{
+  g_ptr_array_add(pat->tags, tags);
+}
 
